cumulusci.tasks.github package
==============================

Subpackages
-----------

.. toctree::

   cumulusci.tasks.github.tests

Submodules
----------


.. automodule:: cumulusci.tasks.github.base
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.merge
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.pull_request
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.release
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.release_report
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tag
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.util
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.github
   :members:
   :undoc-members:
   :show-inheritance:
